# Python for Actuaries
This package contains the code examples for a series of three webinars sponsored by ACTEX Learning:
<ul>
  <li><a href="https://www.actexmadriver.com/product.aspx?id=453140807">Python for Actuaries: Introduction to Data Analysis</a></li>
  <li><a href="https://www.actexmadriver.com/product.aspx?id=453140950">Python for Actuaries: Advanced Data Analysis Techniques</a></li>
  <li><a href="https://www.actexmadriver.com/product.aspx?id=453142503">Statistical Modeling in Python</a></li>
</ul>

Reasons as to why actuaries should evaluate using Python for actuarial calculations appear here:
<ul>
<li><a href="https://blog.actexmadriver.com/2017/10/09/how-python-saved-my-company/">How Python Saved my Company</a></li>
<li><a href="https://blog.actexmadriver.com/2018/01/16/melting-data-in-python-to-discover-6-million-in-missed-risk-adjustment/">Melting Data in Python to Discover $6 Million in Missed Risk Adjustment</a></li>
<li><a href="https://blog.actexmadriver.com/2018/06/13/why-actuaries-should-start-paying-attention-to-python/">Why Actuaries Should Start Paying Attention to Python by Andrew Webster</a></li>
</ul>
